@@ -52,7 +52,7 @@ class CfnByteMatchSet(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_ty
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: aws_cdk.core.Construct, id: str, resource_attributes: typing.Any) -> "CfnByteMatchSet":
+    def from_cloud_formation(cls, scope: aws_cdk.core.Construct, id: str, resource_attributes: typing.Any, *, finder: aws_cdk.core.ICfnFinder) -> "CfnByteMatchSet":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -60,11 +60,14 @@ class CfnByteMatchSet(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_ty
         :param scope: -
         :param id: -
         :param resource_attributes: -
+        :param finder: The finder interface used to resolve references across the template.
 
         stability
         :stability: experimental
         """
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes])
+        options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
+
+        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
@@ -310,7 +313,7 @@ class CfnIPSet(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aw
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: aws_cdk.core.Construct, id: str, resource_attributes: typing.Any) -> "CfnIPSet":
+    def from_cloud_formation(cls, scope: aws_cdk.core.Construct, id: str, resource_attributes: typing.Any, *, finder: aws_cdk.core.ICfnFinder) -> "CfnIPSet":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -318,11 +321,14 @@ class CfnIPSet(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aw
         :param scope: -
         :param id: -
         :param resource_attributes: -
+        :param finder: The finder interface used to resolve references across the template.
 
         stability
         :stability: experimental
         """
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes])
+        options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
+
+        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
@@ -508,7 +514,7 @@ class CfnRule(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: aws_cdk.core.Construct, id: str, resource_attributes: typing.Any) -> "CfnRule":
+    def from_cloud_formation(cls, scope: aws_cdk.core.Construct, id: str, resource_attributes: typing.Any, *, finder: aws_cdk.core.ICfnFinder) -> "CfnRule":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -516,11 +522,14 @@ class CfnRule(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws
         :param scope: -
         :param id: -
         :param resource_attributes: -
+        :param finder: The finder interface used to resolve references across the template.
 
         stability
         :stability: experimental
         """
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes])
+        options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
+
+        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
@@ -726,7 +735,7 @@ class CfnSizeConstraintSet(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, js
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: aws_cdk.core.Construct, id: str, resource_attributes: typing.Any) -> "CfnSizeConstraintSet":
+    def from_cloud_formation(cls, scope: aws_cdk.core.Construct, id: str, resource_attributes: typing.Any, *, finder: aws_cdk.core.ICfnFinder) -> "CfnSizeConstraintSet":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -734,11 +743,14 @@ class CfnSizeConstraintSet(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, js
         :param scope: -
         :param id: -
         :param resource_attributes: -
+        :param finder: The finder interface used to resolve references across the template.
 
         stability
         :stability: experimental
         """
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes])
+        options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
+
+        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
@@ -973,7 +985,7 @@ class CfnSqlInjectionMatchSet(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta,
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: aws_cdk.core.Construct, id: str, resource_attributes: typing.Any) -> "CfnSqlInjectionMatchSet":
+    def from_cloud_formation(cls, scope: aws_cdk.core.Construct, id: str, resource_attributes: typing.Any, *, finder: aws_cdk.core.ICfnFinder) -> "CfnSqlInjectionMatchSet":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -981,11 +993,14 @@ class CfnSqlInjectionMatchSet(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta,
         :param scope: -
         :param id: -
         :param resource_attributes: -
+        :param finder: The finder interface used to resolve references across the template.
 
         stability
         :stability: experimental
         """
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes])
+        options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
+
+        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
@@ -1200,7 +1215,7 @@ class CfnWebACL(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@a
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: aws_cdk.core.Construct, id: str, resource_attributes: typing.Any) -> "CfnWebACL":
+    def from_cloud_formation(cls, scope: aws_cdk.core.Construct, id: str, resource_attributes: typing.Any, *, finder: aws_cdk.core.ICfnFinder) -> "CfnWebACL":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -1208,11 +1223,14 @@ class CfnWebACL(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@a
         :param scope: -
         :param id: -
         :param resource_attributes: -
+        :param finder: The finder interface used to resolve references across the template.
 
         stability
         :stability: experimental
         """
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes])
+        options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
+
+        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
@@ -1475,7 +1493,7 @@ class CfnXssMatchSet(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_typ
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: aws_cdk.core.Construct, id: str, resource_attributes: typing.Any) -> "CfnXssMatchSet":
+    def from_cloud_formation(cls, scope: aws_cdk.core.Construct, id: str, resource_attributes: typing.Any, *, finder: aws_cdk.core.ICfnFinder) -> "CfnXssMatchSet":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -1483,11 +1501,14 @@ class CfnXssMatchSet(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_typ
         :param scope: -
         :param id: -
         :param resource_attributes: -
+        :param finder: The finder interface used to resolve references across the template.
 
         stability
         :stability: experimental
         """
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes])
+        options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
+
+        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
